package App::ucpan;
use strict;
use warnings;
our $VERSION = "1.10";
1;
__END__

=head1 NAME

App::ucpan - improved CPAN modules updater

=head1 DESCRIPTION

See L<ucpan>.

=head1 LICENSE

Copyright (C) KPEE.

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

=head1 AUTHOR

KPEE E<lt>kpee.cpan@gmail.comE<gt>

=cut

